import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { Dialog, DialogContent, DialogDescription, DialogHeader, DialogTitle, DialogTrigger, } from '../../ui/components/dialog.js';
import { useForm } from 'react-hook-form';
import { Input, labelVariants } from '../../ui/components/input.js';
import { useQuery } from '../../utils/use-query.js';
import { useEffect, useState } from 'react';
import { cn } from 'fumadocs-ui/utils/cn';
import { buttonVariants } from 'fumadocs-ui/components/ui/button';
export function OauthDialog({ flow, scheme, setToken, children, }) {
    const [open, setOpen] = useState(false);
    const form = useForm({
        defaultValues: {
            clientId: '',
            clientSecret: '',
        },
    });
    const tokenQuery = useQuery(async (code, state) => {
        const value = scheme.flows.authorizationCode;
        const res = await fetch(value.tokenUrl, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: new URLSearchParams({
                grant_type: 'authorization_code',
                code,
                // note: `state` could be invalid, but server will check it
                redirect_uri: state.redirect_uri,
                client_id: state.client_id,
                client_secret: state.client_secret,
            }),
        });
        if (!res.ok)
            throw new Error(await res.text());
        const { access_token } = (await res.json());
        setToken(access_token);
        setOpen(false);
    });
    useEffect(() => {
        const params = new URLSearchParams(window.location.search);
        const code = params.get('code');
        const state = params.get('state');
        if (!code || !state || flow !== 'authorizationCode')
            return;
        const parsedState = JSON.parse(state);
        setOpen(true);
        form.setValue('clientId', parsedState.client_id);
        form.setValue('clientSecret', parsedState.client_secret);
        tokenQuery.start(code, parsedState);
        window.history.replaceState(null, '', window.location.pathname);
        // eslint-disable-next-line react-hooks/exhaustive-deps -- first page load only
    }, []);
    const authorize = useQuery(async (values) => {
        if (flow === 'authorizationCode') {
            const value = scheme.flows[flow];
            const params = new URLSearchParams();
            params.set('response_type', 'code');
            params.set('client_id', values.clientId);
            params.set('redirect_uri', window.location.href);
            params.set('scope', Object.keys(value.scopes).join('+'));
            params.set('state', JSON.stringify({
                client_id: values.clientId,
                client_secret: values.clientSecret,
                redirect_uri: window.location.href,
            }));
            window.location.replace(`${value.authorizationUrl}?${params.toString()}`);
        }
        if (flow === 'clientCredentials') {
            const value = scheme.flows[flow];
            await fetch(value.tokenUrl, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: new URLSearchParams({
                    grant_type: 'client_credentials',
                    scope: Object.keys(value.scopes).join('+'),
                }),
            });
        }
    });
    const onSubmit = form.handleSubmit((values) => {
        return authorize.start(values);
    });
    const isLoading = authorize.isLoading || tokenQuery.isLoading;
    return (_jsxs(Dialog, { open: open, onOpenChange: setOpen, children: [children, _jsxs(DialogContent, { children: [_jsxs(DialogHeader, { children: [_jsx(DialogTitle, { children: "Authorization" }), _jsx(DialogDescription, { children: "Obtain the access token for API." })] }), _jsxs("form", { className: "flex flex-col gap-6", onSubmit: onSubmit, children: [(flow === 'authorizationCode' || flow === 'clientCredentials') && (_jsxs(_Fragment, { children: [_jsxs("fieldset", { className: "flex flex-col gap-1.5", children: [_jsx("label", { htmlFor: "client_id", className: cn(labelVariants()), children: "Client ID" }), _jsx("p", { className: "text-fd-muted-foreground text-sm", children: "The client ID of your OAuth application." }), _jsx(Input, { id: "client_id", placeholder: "Enter value", type: "text", disabled: isLoading, ...form.register('clientId', { required: true }) })] }), _jsxs("fieldset", { className: "flex flex-col gap-1.5", children: [_jsx("label", { htmlFor: "client_secret", className: cn(labelVariants()), children: "Client Secret" }), _jsx("p", { className: "text-fd-muted-foreground text-sm", children: "The client secret of your OAuth application." }), _jsx(Input, { id: "client_secret", placeholder: "Enter value", type: "password", disabled: isLoading, ...form.register('clientSecret', { required: true }) })] })] })), tokenQuery.error ? (_jsx("p", { className: "text-red-400 font-medium text-sm", children: String(tokenQuery.error) })) : null, _jsx("button", { disabled: isLoading, className: cn(buttonVariants({
                                    color: 'primary',
                                })), children: tokenQuery.isLoading ? 'Fetching token...' : 'Submit' })] })] })] }));
}
export const OauthDialogTrigger = DialogTrigger;
