import { type FC, type HTMLAttributes, type ReactElement } from 'react';
import type { ControllerFieldState, ControllerRenderProps, FieldPath, UseFormStateReturn } from 'react-hook-form';
import type { FetchResult } from '../playground/fetcher.js';
import type { ParameterField, RequestSchema } from '../playground/index.js';
import type { Security } from '../utils/get-security.js';
interface FormValues {
    authorization: string | {
        username: string;
        password: string;
    };
    path: Record<string, string>;
    query: Record<string, string>;
    header: Record<string, string>;
    cookie: Record<string, string>;
    body: unknown;
}
export interface CustomField<TName extends FieldPath<FormValues>, Info> {
    render: (props: {
        /**
         * Field Info
         */
        info: Info;
        field: ControllerRenderProps<FormValues, TName>;
        fieldState: ControllerFieldState;
        formState: UseFormStateReturn<FormValues>;
    }) => ReactElement;
}
export type ClientProps = HTMLAttributes<HTMLFormElement> & {
    route: string;
    method: string;
    authorization?: Security & {
        persistentId: string;
    };
    parameters?: ParameterField[];
    body?: {
        schema: RequestSchema;
        mediaType: string;
    };
    /**
     * Resolver for $ref schemas you've passed
     */
    references: Record<string, RequestSchema>;
    proxyUrl?: string;
    fields?: {
        parameter?: CustomField<`${ParameterField['in']}.${string}`, ParameterField>;
        auth?: CustomField<'authorization', RequestSchema>;
        body?: CustomField<'body', RequestSchema>;
    };
    components?: Partial<{
        ResultDisplay: FC<{
            data: FetchResult;
        }>;
    }>;
};
export default function Client({ route, method, authorization, parameters, body, fields, references, proxyUrl, components: { ResultDisplay }, ...rest }: ClientProps): import("react/jsx-runtime").JSX.Element;
export {};
//# sourceMappingURL=client.d.ts.map