'use client';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState, } from 'react';
import { Plus, Trash2 } from '../icons.js';
import { Controller, useController, useFieldArray, useFormContext, } from 'react-hook-form';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue, } from '../ui/components/select.js';
import { Input, labelVariants } from '../ui/components/input.js';
import { getDefaultValue } from './get-default-values.js';
import { cn } from 'fumadocs-ui/utils/cn';
import { buttonVariants } from 'fumadocs-ui/components/ui/button';
import { combineSchema } from '../utils/combine-schema.js';
import { schemaToString } from '../utils/schema-to-string.js';
import { anyFields, useFieldInfo, useResolvedSchema, } from '../playground/schema.js';
function FieldHeader({ name, required = false, type, ...props }) {
    return (_jsxs("label", { ...props, className: cn('w-full inline-flex items-center gap-1', props.className), children: [_jsxs("span", { className: cn(labelVariants()), children: [name, required ? _jsx("span", { className: "text-red-400/80 mx-1", children: "*" }) : null] }), _jsx("div", { className: "flex-1" }), type ? (_jsx("code", { "data-type": true, className: "text-xs text-fd-muted-foreground", children: type })) : null, props.children] }));
}
export function ObjectInput({ field: _field, fieldName, ...props }) {
    const field = useResolvedSchema(combineSchema([_field, ...(_field.allOf ?? []), ...(_field.anyOf ?? [])]));
    return (_jsxs("div", { ...props, className: cn('flex flex-col gap-6', props.className), children: [Object.entries(field.properties ?? {}).map(([key, child]) => (_jsx(FieldSet, { name: key, field: child, fieldName: `${fieldName}.${key}`, isRequired: field.required?.includes(key) }, key))), (field.additionalProperties || field.patternProperties) && (_jsx(DynamicProperties, { fieldName: fieldName, filterKey: (v) => !field.properties || !Object.keys(field.properties).includes(v), getType: (key) => {
                    for (const pattern in field.patternProperties) {
                        if (key.match(RegExp(pattern))) {
                            return field.patternProperties[pattern];
                        }
                    }
                    if (field.additionalProperties)
                        return field.additionalProperties;
                    return anyFields;
                } }))] }));
}
export function JsonInput({ fieldName, children, }) {
    const controller = useController({
        name: fieldName,
    });
    const [value, setValue] = useState(() => JSON.stringify(controller.field.value, null, 2));
    return (_jsxs("div", { className: "rounded-lg border bg-fd-secondary text-fd-secondary-foreground", children: [children, _jsx("textarea", { ...controller.field, value: value, className: "p-2 w-full h-[240px] text-[13px] font-mono resize-none focus-visible:outline-none", onChange: (v) => {
                    setValue(v.target.value);
                    try {
                        controller.field.onChange(JSON.parse(v.target.value));
                    }
                    catch {
                        // ignore
                    }
                } })] }));
}
function DynamicProperties({ fieldName, filterKey = () => true, getType = () => anyFields, }) {
    const { control, setValue, getValues } = useFormContext();
    const [nextName, setNextName] = useState('');
    const [properties, setProperties] = useState(() => {
        const value = getValues(fieldName);
        if (value)
            return Object.keys(value).filter(filterKey);
        return [];
    });
    const onAppend = () => {
        const name = nextName.trim();
        if (name.length === 0)
            return;
        setProperties((p) => {
            if (p.includes(name) || !filterKey(name))
                return p;
            const type = getType(name);
            setValue(`${fieldName}.${name}`, getDefaultValue(type));
            setNextName('');
            return [...p, name];
        });
    };
    return (_jsxs(_Fragment, { children: [properties.map((item) => (_jsx(FieldSet, { name: item, field: getType(item), fieldName: `${fieldName}.${item}`, toolbar: _jsx("button", { type: "button", "aria-label": "Remove Item", className: cn(buttonVariants({
                        color: 'ghost',
                        className: 'p-1',
                    })), onClick: () => {
                        setProperties((p) => p.filter((prop) => prop !== item));
                        control.unregister(`${fieldName}.${item}`);
                    }, children: _jsx(Trash2, { className: "size-4" }) }) }, item))), _jsxs("div", { className: "flex gap-2", children: [_jsx(Input, { value: nextName, placeholder: "Enter Property Name", onChange: (e) => setNextName(e.target.value), onKeyDown: (e) => {
                            if (e.key === 'Enter') {
                                onAppend();
                                e.preventDefault();
                            }
                        } }), _jsx("button", { type: "button", className: cn(buttonVariants({ color: 'secondary', size: 'sm' }), 'px-4'), onClick: onAppend, children: "New" })] })] }));
}
export function FieldInput({ field, fieldName, isRequired, ...props }) {
    const { control, register } = useFormContext();
    if (field.type === 'object') {
        return (_jsx(ObjectInput, { field: field, fieldName: fieldName, ...props, className: cn('rounded-lg border border-fd-primary/20 bg-fd-background/50 p-3 shadow-sm', props.className) }));
    }
    if (field.type === 'array') {
        return (_jsx(ArrayInput, { fieldName: fieldName, items: field.items ?? anyFields, ...props, className: cn('rounded-lg border border-fd-primary/20 bg-fd-background/50 p-3 shadow-sm', props.className) }));
    }
    if (field.type === 'string' && field.format === 'binary') {
        return (_jsx(Controller, { control: control, name: fieldName, render: ({ field: { value: _, onChange, ...restField } }) => (_jsx("input", { id: fieldName, type: "file", multiple: false, onChange: (e) => {
                    if (!e.target.files)
                        return;
                    onChange(e.target.files.item(0));
                }, ...props, className: cn('border rounded-lg bg-fd-background text-fd-muted-foreground p-2 font-medium text-sm', props.className), ...restField })) }));
    }
    if (field.type === 'boolean') {
        return (_jsx(Controller, { control: control, name: fieldName, render: ({ field: { value, onChange, ...restField } }) => (_jsxs(Select, { value: String(value), onValueChange: (value) => onChange(value === 'null' ? null : value === 'true'), disabled: restField.disabled, children: [_jsx(SelectTrigger, { id: fieldName, className: props.className, ...restField, children: _jsx(SelectValue, {}) }), _jsxs(SelectContent, { children: [_jsx(SelectItem, { value: "true", children: "True" }), _jsx(SelectItem, { value: "false", children: "False" }), !isRequired && _jsx(SelectItem, { value: "null", children: "Null" })] })] })) }));
    }
    return (_jsx(Input, { id: fieldName, placeholder: "Enter value", type: field.type === 'string' ? 'text' : 'number', ...register(fieldName, {
            valueAsNumber: field.type === 'number' || field.type === 'integer',
        }), ...props }));
}
export function FieldSet({ field: _field, fieldName, toolbar, name, isRequired, depth = 0, ...props }) {
    const field = useResolvedSchema(_field);
    const [show, setShow] = useState(() => typeof _field !== 'object' ||
        !_field.$ref ||
        (field.type !== 'object' && !field.allOf && !field.oneOf && !field.anyOf));
    const { info, updateInfo } = useFieldInfo(fieldName, field, depth);
    if (_field === false)
        return null;
    if (!show) {
        return (_jsxs(FieldHeader, { ...props, name: name, required: isRequired, children: [toolbar, _jsx("button", { type: "button", className: cn(buttonVariants({ size: 'sm' })), onClick: () => setShow(true), children: "Show" })] }));
    }
    if (field.oneOf) {
        return (_jsx(FieldSet, { ...props, className: cn(props.className, '[&>label>[data-type]]:hidden'), name: name, fieldName: fieldName, isRequired: isRequired, field: field.oneOf[info.oneOf], depth: depth + 1, toolbar: _jsxs(_Fragment, { children: [_jsx("select", { className: "text-xs font-mono", value: info.oneOf, onChange: (e) => {
                            updateInfo({
                                oneOf: Number(e.target.value),
                            });
                        }, children: field.oneOf.map((item, i) => (_jsx("option", { value: i, children: schemaToString(item) }, i))) }), toolbar] }) }));
    }
    if (Array.isArray(field.type)) {
        return (_jsxs("fieldset", { ...props, className: cn('flex flex-col gap-1.5', props.className), children: [_jsxs(FieldHeader, { name: name, htmlFor: fieldName, required: isRequired, children: [_jsx("select", { className: "text-xs font-mono", value: info.selectedType, onChange: (e) => {
                                updateInfo({
                                    selectedType: e.target.value,
                                });
                            }, children: field.type.map((item) => (_jsx("option", { value: item, children: item }, item))) }), toolbar] }), _jsx("p", { className: "text-xs text-fd-muted-foreground", children: field.description }), _jsx(FieldInput, { isRequired: isRequired, field: {
                        ...field,
                        type: info.selectedType,
                    }, fieldName: fieldName })] }));
    }
    return (_jsxs("fieldset", { ...props, className: cn('flex flex-col gap-1.5', props.className), children: [_jsx(FieldHeader, { htmlFor: fieldName, name: name, required: isRequired, type: field.oneOf ? undefined : schemaToString(field), children: toolbar }), show ? (_jsx(FieldInput, { field: field, fieldName: fieldName, isRequired: isRequired })) : (_jsx("div", { children: _jsx("button", { onClick: () => setShow((prev) => !prev), children: "Show" }) }))] }));
}
function ArrayInput({ fieldName, items, ...props }) {
    const name = fieldName.split('.').at(-1) ?? '';
    const { fields, append, remove } = useFieldArray({
        name: fieldName,
    });
    return (_jsxs("div", { ...props, className: cn('flex flex-col gap-2', props.className), children: [fields.map((item, index) => (_jsx(FieldSet, { name: _jsxs("span", { className: "text-fd-muted-foreground", children: [name, "[", index, "]"] }), field: items, fieldName: `${fieldName}.${index}`, toolbar: _jsx("button", { type: "button", "aria-label": "Remove Item", className: cn(buttonVariants({
                        color: 'ghost',
                        className: 'p-1',
                    })), onClick: () => remove(index), children: _jsx(Trash2, { className: "size-4" }) }) }, item.id))), _jsxs("button", { type: "button", className: cn(buttonVariants({
                    color: 'outline',
                    className: 'gap-1.5 py-2',
                    size: 'sm',
                })), onClick: () => {
                    append(getDefaultValue(items));
                }, children: [_jsx(Plus, { className: "size-4" }), "New Item"] })] }));
}
