import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { combineSchema } from '../utils/combine-schema.js';
import { Markdown } from './markdown.js';
import { schemaToString } from '../utils/schema-to-string.js';
const keys = {
    default: 'Default',
    minimum: 'Minimum',
    maximum: 'Maximum',
    minLength: 'Minimum length',
    maxLength: 'Maximum length',
    pattern: 'Pattern',
    format: 'Format',
};
export function Schema({ name, schema, required = false, parseObject = true, ctx, }) {
    const { render: { renderer }, stack = [], } = ctx;
    if (schema === true) {
        return _jsx(renderer.Property, { name: name, type: "any" });
    }
    else if (schema === false) {
        return _jsx(renderer.Property, { name: name, type: "never" });
    }
    if ((schema.readOnly === true && !ctx.readOnly) ||
        (schema.writeOnly === true && !ctx.writeOnly))
        return null;
    if (Array.isArray(schema.type) && schema.type.length === 1) {
        return (_jsx(Schema, { name: name, required: required, parseObject: parseObject, schema: {
                ...schema,
                type: schema.type[0],
            }, ctx: {
                ...ctx,
                stack: [schema, ...stack],
            } }));
    }
    if (schema.allOf || schema.anyOf) {
        return (_jsx(Schema, { name: name, parseObject: parseObject, required: required, schema: combineSchema([
                ...(schema.allOf ?? []),
                ...(schema.anyOf ?? []),
            ]), ctx: {
                ...ctx,
                stack: [schema, ...stack],
            } }));
    }
    // object type
    if (schema.type === 'object' && parseObject) {
        const { additionalProperties, patternProperties, properties } = schema;
        return (_jsxs("div", { className: "flex flex-col gap-4", children: [properties &&
                    Object.entries(properties).map(([key, value]) => {
                        return (_jsx(Schema, { name: key, schema: value, parseObject: false, required: schema.required?.includes(key) ?? false, ctx: {
                                ...ctx,
                                stack: [schema, ...stack],
                            } }, key));
                    }), patternProperties &&
                    Object.entries(patternProperties).map(([key, value]) => {
                        return (_jsx(Schema, { name: key, schema: value, parseObject: false, ctx: {
                                ...ctx,
                                stack: [schema, ...stack],
                            } }, key));
                    }), additionalProperties && (_jsx(Schema, { name: "[key: string]", schema: additionalProperties, parseObject: false, ctx: {
                        ...ctx,
                        stack: [schema, ...stack],
                    } }))] }));
    }
    let footer;
    const fields = [];
    for (const [key, value] of Object.entries(keys)) {
        if (key in schema) {
            fields.push({
                key: value,
                value: JSON.stringify(schema[key]),
            });
        }
    }
    if (schema.enum) {
        fields.push({
            key: 'Value in',
            value: schema.enum.map((value) => JSON.stringify(value)).join(' | '),
        });
    }
    if (schema.type === 'object' && !parseObject && !stack.includes(schema)) {
        footer = (_jsx(renderer.ObjectCollapsible, { name: "Show Attributes", children: _jsx(Schema, { name: name, schema: schema, ctx: {
                    ...ctx,
                    stack: [schema, ...stack],
                } }) }));
    }
    else {
        let mentionedObjectTypes = [];
        if (Array.isArray(schema.type)) {
            mentionedObjectTypes.push(...schema.type.map((type) => ({
                ...schema,
                type,
            })));
        }
        if (schema.oneOf)
            mentionedObjectTypes.push(...schema.oneOf);
        if (schema.not)
            mentionedObjectTypes.push(schema.not);
        if (schema.type === 'array' && schema.items)
            mentionedObjectTypes.push(schema.items);
        mentionedObjectTypes = mentionedObjectTypes.filter((s) => isComplexType(s) && !stack.includes(s));
        if (mentionedObjectTypes.length > 0)
            footer = (_jsx("div", { className: "flex flex-col gap-2", children: mentionedObjectTypes.map((s, idx) => {
                    let title = typeof s === 'object' ? s.title : null;
                    title ?? (title = mentionedObjectTypes.length === 1
                        ? 'Show Attributes'
                        : `Object ${idx + 1}`);
                    return (_jsx(renderer.ObjectCollapsible, { name: title, children: _jsx(Schema, { name: "element", schema: s, ctx: {
                                ...ctx,
                                stack: [schema, ...stack],
                            } }) }, idx));
                }) }));
    }
    return (_jsxs(renderer.Property, { name: name, type: schemaToString(schema), required: required, deprecated: schema.deprecated, children: [schema.description ? _jsx(Markdown, { text: schema.description }) : null, fields.length > 0 ? (_jsx("div", { className: "flex flex-col gap-2", children: fields.map((field) => (_jsxs("span", { children: [field.key, ": ", _jsx("code", { children: field.value })] }, field.key))) })) : null, footer] }));
}
/**
 * Check if the schema needs another collapsible to explain
 */
function isComplexType(schema) {
    if (typeof schema === 'boolean')
        return false;
    if (schema.anyOf ?? schema.oneOf ?? schema.allOf)
        return true;
    return schema.type === 'object' || schema.type === 'array';
}
