/**
 * Combine multiple object schemas into one
 */
export function combineSchema(schema) {
    let result = {
        type: undefined,
    };
    function add(s) {
        if (typeof s === 'boolean') {
            result = s;
            return;
        }
        if (typeof result === 'boolean')
            return;
        if (s.type) {
            result.type ?? (result.type = []);
            if (!Array.isArray(result.type)) {
                result.type = [result.type];
            }
            for (const v of Array.isArray(s.type) ? s.type : [s.type]) {
                if (Array.isArray(result.type) && !result.type.includes(v)) {
                    result.type.push(v);
                }
            }
        }
        if (s.properties) {
            result.properties ?? (result.properties = {});
            Object.assign(result.properties, s.properties);
        }
        if (s.patternProperties) {
            result.patternProperties ?? (result.patternProperties = {});
            Object.assign(result.patternProperties, s.patternProperties);
        }
        if (s.additionalProperties === true) {
            result.additionalProperties = true;
        }
        else if (s.additionalProperties &&
            typeof result.additionalProperties !== 'boolean') {
            result.additionalProperties ?? (result.additionalProperties = {});
            Object.assign(result.additionalProperties, s.additionalProperties);
        }
        if (s.required) {
            result.required ?? (result.required = []);
            result.required.push(...s.required);
        }
        if (s.enum && s.enum.length > 0) {
            result.enum ?? (result.enum = []);
            result.enum.push(...s.enum);
        }
        if (s.allOf) {
            s.allOf.forEach(add);
        }
    }
    schema.forEach(add);
    return result;
}
