import { dereference, load, upgrade } from '@scalar/openapi-parser';
import { fetchUrls } from '@scalar/openapi-parser/plugins/fetch-urls';
import { readFiles } from '@scalar/openapi-parser/plugins/read-files';
const cache = new Map();
/**
 * process & reference input document to a Fumadocs OpenAPI compatible format
 */
export async function processDocument(document, disableCache = false) {
    const cached = !disableCache && typeof document === 'string' ? cache.get(document) : null;
    if (cached)
        return cached;
    const dereferenceMap = new Map();
    const loaded = await load(document, {
        plugins: [readFiles(), fetchUrls()],
    });
    // upgrade
    loaded.specification = upgrade(loaded.specification).specification;
    const { schema: dereferenced } = await dereference(loaded.filesystem, {
        onDereference({ ref, schema }) {
            dereferenceMap.set(schema, ref);
        },
    });
    const processed = {
        document: dereferenced,
        dereferenceMap,
        downloaded: loaded.specification,
    };
    if (!disableCache && typeof document === 'string') {
        cache.set(document, processed);
    }
    return processed;
}
